TrackInfo class

This type is used by MediaInfo to show information about a track. Only type is guaranteed to be non-null. Other information may not be available and can be different on different platforms.

Constructors

TrackInfo(TrackType type, {bool? isHdr, String? format, String? language, String? title, Size? videoSize, double? frameRate, int? bitRate, int? channels, int? sampleRate})
const

Properties

bitRate → int?
final
channels → int?
final
format → String?
final
frameRate → double?
final
hashCode → int
The hash code for this object.
no setterinherited
isHdr → bool?
final
language → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate → int?
final
title → String?
final
type → TrackType
final
videoSize → Size?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → TrackInfo