AvMediaView class

The widget to display video for AvMediaPlayer.

Inheritance

Constructors

AvMediaView({Key? key, AvMediaPlayer? initPlayer, String? initSource, bool? initAutoPlay, bool? initLooping, double? initVolume, double? initSpeed, int? initPosition, bool? initShowSubtitle, String? initPreferredSubtitleLanguage, String? initPreferredAudioLanguage, int? initMaxBitRate, Size? initMaxResolution, void onCreated(AvMediaPlayer player)?, Color? backgroundColor, SizingMode sizingMode = SizingMode.keepAspectRatio})
Create a new AvMediaView widget. If initPlayer is null, a new player will be created. You can get the player from onCreated callback.
const

Properties

backgroundColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
initAutoPlay → bool?
final
initLooping → bool?
final
initMaxBitRate → int?
final
initMaxResolution → Size?
final
initPlayer → AvMediaPlayer?
final
initPosition → int?
final
initPreferredAudioLanguage → String?
final
initPreferredSubtitleLanguage → String?
final
initShowSubtitle → bool?
final
initSource → String?
final
initSpeed → double?
final
initVolume → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCreated → void Function(AvMediaPlayer player)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizingMode → SizingMode
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AvMediaView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited